summaryrefslogtreecommitdiff
path: root/deps/uv/src/unix/internal.h
diff options
context:
space:
mode:
authorisaacs <i@izs.me>2013-06-26 10:48:10 -0700
committerisaacs <i@izs.me>2013-06-26 10:48:23 -0700
commit4bc024ddecf4e0daaa5d28155d3ad5977b98a68e (patch)
treeeba928832aeb353981a5197998721d61c9748dc5 /deps/uv/src/unix/internal.h
parent4ae96c885bd3118a1f19972b90aabbc83cf5b20b (diff)
downloadandroid-node-v8-4bc024ddecf4e0daaa5d28155d3ad5977b98a68e.tar.gz
android-node-v8-4bc024ddecf4e0daaa5d28155d3ad5977b98a68e.tar.bz2
android-node-v8-4bc024ddecf4e0daaa5d28155d3ad5977b98a68e.zip
uv: Upgrade to v0.11.5
Diffstat (limited to 'deps/uv/src/unix/internal.h')
-rw-r--r--deps/uv/src/unix/internal.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/deps/uv/src/unix/internal.h b/deps/uv/src/unix/internal.h
index 2f4d526a61..9b593d9ea1 100644
--- a/deps/uv/src/unix/internal.h
+++ b/deps/uv/src/unix/internal.h
@@ -99,17 +99,19 @@
/* handle flags */
enum {
- UV_CLOSING = 0x01, /* uv_close() called but not finished. */
- UV_CLOSED = 0x02, /* close(2) finished. */
- UV_STREAM_READING = 0x04, /* uv_read_start() called. */
- UV_STREAM_SHUTTING = 0x08, /* uv_shutdown() called but not complete. */
- UV_STREAM_SHUT = 0x10, /* Write side closed. */
- UV_STREAM_READABLE = 0x20, /* The stream is readable */
- UV_STREAM_WRITABLE = 0x40, /* The stream is writable */
- UV_STREAM_BLOCKING = 0x80, /* Synchronous writes. */
- UV_TCP_NODELAY = 0x100, /* Disable Nagle. */
- UV_TCP_KEEPALIVE = 0x200, /* Turn on keep-alive. */
- UV_TCP_SINGLE_ACCEPT = 0x400 /* Only accept() when idle. */
+ UV_CLOSING = 0x01, /* uv_close() called but not finished. */
+ UV_CLOSED = 0x02, /* close(2) finished. */
+ UV_STREAM_READING = 0x04, /* uv_read_start() called. */
+ UV_STREAM_SHUTTING = 0x08, /* uv_shutdown() called but not complete. */
+ UV_STREAM_SHUT = 0x10, /* Write side closed. */
+ UV_STREAM_READABLE = 0x20, /* The stream is readable */
+ UV_STREAM_WRITABLE = 0x40, /* The stream is writable */
+ UV_STREAM_BLOCKING = 0x80, /* Synchronous writes. */
+ UV_STREAM_READ_PARTIAL = 0x100, /* read(2) read less than requested. */
+ UV_STREAM_READ_EOF = 0x200, /* read(2) read EOF. */
+ UV_TCP_NODELAY = 0x400, /* Disable Nagle. */
+ UV_TCP_KEEPALIVE = 0x800, /* Turn on keep-alive. */
+ UV_TCP_SINGLE_ACCEPT = 0x1000 /* Only accept() when idle. */
};
/* core */
@@ -142,7 +144,6 @@ void uv__run_prepare(uv_loop_t* loop);
/* error */
uv_err_code uv_translate_sys_error(int sys_errno);
-void uv_fatal_error(const int errorno, const char* syscall);
/* stream */
void uv__stream_init(uv_loop_t* loop, uv_stream_t* stream,